import { ModuleMetadata, Type } from '@nestjs/common';
import { RedisOptions, Redis } from 'ioredis';
import { ClientNamespace } from '../types';
/** Redis连接配置 */
export interface ClientOptions extends RedisOptions {
    /** Redis客户端名词空间 */
    namespace?: ClientNamespace;
    /**
     * 客户端创建完成时的回调
     * @param client - The client.
     */
    onClientCreated?: (client: Redis) => void;
}
/** 同步传入配置 */
export interface RedisModuleOptions {
    /** 每个客户端的默认配置 */
    defaultOptions?: RedisOptions;
    /** 客户端单独配置 */
    config?: ClientOptions | ClientOptions[];
}
export interface RedisOptionsFactory {
    createRedisOptions(): RedisModuleOptions | Promise<RedisModuleOptions>;
}
/** 异步传入配置 */
export interface RedisModuleAsyncOptions extends Pick<ModuleMetadata, 'imports'> {
    useExisting?: Type<RedisOptionsFactory>;
    useClass?: Type<RedisOptionsFactory>;
    useFactory?: (...args: any[]) => RedisModuleOptions | Promise<RedisModuleOptions>;
    inject?: any[];
}
